@@ -1,4 +1,5 @@
 from .http import Http
+from .util import Util
 import json
 
 class User:
@@ -29,7 +30,7 @@ class Users:
 		except:
 			return False
 
-	def User(username):
+	def getUser(username):
 		try:
 			res = Http.sendRequest("https://api.roblox.com/users/get-by-username?username=" + str(username))
 			res_decoded = res.decode("utf-8")
@@ -39,24 +40,29 @@ class Users:
 		except:
 			return None
 
-	def BodyColors(id):
+	def getBodyColors(id):
 		res = Http.sendRequest("https://www.roblox.com/Asset/BodyColors.ashx?userId=" + str(id))
 		return res
 
-	def AssetsWorn(id):
+	def getAssetsWorn(id):
 		res = Http.sendRequest("https://www.roblox.com/Asset/AvatarAccoutrements.ashx?userId=" + str(id))
 		return res
 
-	def AssetVersions(id, placeid):
+	def getAssetVersions(id, placeid):
 		res = Http.sendRequest(
 			"https://www.roblox.com/Asset/CharacterFetch.ashx?userId=" + str(id) + "&placeId=" + str(placeid))
 		return res
 
-	def Places(id):
+	def getPlaces(id):
 		res = Http.sendRequest("https://www.roblox.com/Contests/Handlers/Showcases.ashx?userId=" + str(id))
 		return res
 
-	def Badges(id):
+	def getBadges(id):
 		res = Http.sendRequest(
 			"https://www.roblox.com/badges/roblox?userId=" + str(id) + "&imgWidth=110&imgHeight=110&imgFormat=png")
-		return res
\ No newline at end of file
+		return res
+	
+	# New Cmds
+
+	def login(token):
+		Util.login(token)
\ No newline at end of file
